Index: branches/features/purchaseOrders/scripts/_UpdateRev.groovy
===================================================================
--- branches/features/purchaseOrders/scripts/_UpdateRev.groovy	(revision 889)
+++ branches/features/purchaseOrders/scripts/_UpdateRev.groovy	(revision 920)
@@ -114,9 +114,9 @@
             return fail(code:"vcs.working.copy.not.found", args:[basedir])
 
     // Use svnkit to get the base revision.
     def clientManager = SVNClientManager.newInstance()
     def wcClient = clientManager.getWCClient()
     try {
-        result.revision = wcClient.doInfo(wc, SVNRevision.BASE).getRevision().toString()
+        result.revision = wcClient.doInfo(wc, SVNRevision.BASE).getCommittedRevision().toString()
     }
     catch(org.tmatesoft.svn.core.SVNException e) {
@@ -114,9 +114,9 @@
             return fail(code:"vcs.working.copy.not.found", args:[basedir])
 
-    // Use svnkit to get the base revision.
+    // Use svnkit to get the last committed revision.
     def clientManager = SVNClientManager.newInstance()
     def wcClient = clientManager.getWCClient()
